Welcome to symfit’s documentation! — symfit 0.2 documentation

### Navigation

- index
- next |
- symfit 0.2 documentation »

# Welcome to symfit’s documentation!

Contents:

- Introduction
- Tutorial

# Indices and tables

- Index
- Module Index
- Search Page

### Table Of Contents

- Welcome to symfit’s documentation!
- Indices and tables

#### Next topic

Introduction

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- next |
- symfit 0.2 documentation »

© Copyright 2014, tBuLi. Created using Sphinx 1.2.3.